package com.fuzamei.web;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.alibaba.fastjson.JSON;
import com.fuzamei.constant.HintMSG;
import com.fuzamei.entity.Role;
import com.fuzamei.entity.User;
import com.fuzamei.service.UserAuthoricationService;
import com.fuzamei.service.UserService;
import com.fuzamei.util.JSONUtil;
import com.fuzamei.util.ValidationUtil;

@RestController
@RequestMapping(path="/user")
public class UserAction {
	@Autowired
	private UserService userService;
	@Autowired
	private UserAuthoricationService userAuthoricationService;

	/**
	 * 查询*得到所有的角色
	 * @return
	 */
	@PostMapping(value = "getAllRoles")
	public Map<String,Object> getAllRoles(){
		Map<String,Object> resultMap = new LinkedHashMap<String,Object>();
		List<Role> roles = new ArrayList<Role>();
		try {
			 roles = userService.getAllRoles();
			resultMap = JSONUtil.getJsonMap(200, true, "获取角色信息成功", roles);
		} catch (Exception e) {
			resultMap = JSONUtil.getJsonMap(500, false, "获取角色信息失败", roles);
		}
		return resultMap;
	}
	/**
	 {
      "user_id":"1001",
      "roleId":"3",
      "username":"",
      "personName":""
      }
	      查看账户列表
	 * @param data
	 * @return
	 */
	@PostMapping(value="/queryUsers")
	public Map<String, Object> queryUsers(@RequestBody String  data){
		try {
			@SuppressWarnings("unchecked")
			Map<String, Object> map = JSON.parseObject(data,Map.class);//将前端传过来的json数据转化为map对象，并将map对象传入service层进行数据校验
			Integer user_id = ValidationUtil.checkAndAssignInt(map.get("user_id"));//————————————》TODO  待
			//System.out.println(user_id+"aaaaaaaaaaaaaaaaaaaaaaa");
			//userAuthoricationService.queryUserAuthority(ValidationUtil.checkAndAssignInt(map.get("user_id"), com.fuzamei.constant.Role.ADMIN)); 
			Integer roleId=ValidationUtil.checkAndAssignNullIntegerIfIsBlank(map.get("roleId"));
			String username=ValidationUtil.checkBlankStringAndAssignEmptyIfIsBlank(map.get("username"));//拿到前端传来的账号去service校验
			String personName=ValidationUtil.checkBlankStringAndAssignEmptyIfIsBlank(map.get("personName"));
			Map<String, Object> mapToService = new LinkedHashMap<String, Object>();
			mapToService.put("user_id",user_id );
			mapToService.put("roleId",roleId );
			mapToService.put("username", username);
			mapToService.put("personName", personName);
			List<User> list=userService.queryUsers(mapToService);
			return JSONUtil.getJsonMap(200, true, HintMSG.QUERY_SUCCESS, list);
		} catch (Exception e) {
			return JSONUtil.getJsonMap(500, false, HintMSG.QUERY_FAIL+":"+e.getMessage(), null);
		}
	
	}
	/**
	 * 编辑修改
	 * 根据用户id修改账号，密码，名称，角色，信息
	 * @param data
	 * @return
		{ 	
	      "userId": "5556",
	      "username": "王五998",
	      "password": "123456",
	      "roleId": "1",
	      "personName": "张三7"
	    } 
	 */
	@PostMapping(value="/updateAccountByUserId")
	public Map<String, Object> updateAccountByUserId(@RequestBody  User  user){
		try {
			
			ValidationUtil.checkAndAssignInt(user.getUserId());
	         List<User> us=userService.findUserByuserIdandusername(user);
	        if(us==null||us.size()<1) {
	        	userService.updateAccountByUserId(user);
	        	return JSONUtil.getJsonMap(200, true, "修改成功", null);
	        }else {
	        	return JSONUtil.getJsonMap(500, false, "修改失败,该账号已存在了", null);
	        }
			
		} catch (Exception e) {
			return JSONUtil.getJsonMap(500, false, "修改失败", null);
		}
		
     }
	
	/**
	 * 添加用户
	 * @param user
	 * @param result
	 * @return
		{ 	
	      "userId": "5556",
	      "username": "王五998",
	      "password": "123456",
	      "roleId": "1",
	      "personName": "张三7"
	    } 
	 */
	@PostMapping(value = "/insertUsers")
	public Map<String,Object> insertUsers(@RequestBody User  user){
        //是否还要校验密码？？？？？？
		try {
			 ValidationUtil.checkAndAssignInt(user.getUserId());
	         List<User> us=userService.findUserById(user);
	         if(us==null||us.size()<1) {
	        	userService.insertUsers(user);
	        	return JSONUtil.getJsonMap(200, true, "添加成功", null);
	         }else {
	        	return JSONUtil.getJsonMap(500, false, "用户已存在，添加失败", null);
	         }
		} catch (Exception e) {
			return JSONUtil.getJsonMap(500, false, "添加失败", null);
		}
	}
	
	/**
	      让前端传过来Id{1001,1002,1003,1004}以逗号隔开
	   "userids" ——》1，2，3，4，5，6
	 * @param userIds
	 * @return
	 */
/*	@PostMapping(value="/deleteFromUserId")
	public  Map<String,Object> deleteFromUserId(String userIds){
		try {
			userService.deleteFromUserId(userIds);
			return JSONUtil.getJsonMap(200, true, "删除成功", null);
		} catch (Exception e) {
			return JSONUtil.getJsonMap(500, false, "删除失败", null);
		}
		
	}*/
	@PostMapping(value="/deleteFromUserId")
	public  Map<String,Object> deleteFromUserId(@RequestBody String data){
		try {
			@SuppressWarnings("unchecked")
			Map<String, Object> map = JSON.parseObject(data,Map.class);
			String userIds=ValidationUtil.checkBlankStringAndAssignEmptyIfIsBlank(map.get("userIds"));//校验前端传来的参数（userIds）XXX
			userService.deleteFromUserId(userIds);
			return JSONUtil.getJsonMap(200, true, "删除成功", null);
		} catch (Exception e) {
			return JSONUtil.getJsonMap(500, false, "删除失败", null);
		}
		
	}
	
	
	
	
	
	
}
